﻿<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:my="http://reports.org">
<xsl:output method="html" doctype-system="about:legacy-compat" encoding="ISO-8859-1" indent="yes" />

<xsl:template match="my:reports">
<xsl:variable name="No" select="count(//my:delivered)"/>
<html>

<!-- HEAD (HTML STYLE) -->

  <head>
    <style>
      h1 {font-variant: small-caps}
      h2 {background-color: #138a94; padding:3px; font-variant: small-caps}
      <!-- dark teal -->
      h3 {background-color: #8cc3db; margin-left: 6px; padding:3px; font-variant: small-caps}
      <!-- light teal -->

      #note {font-size:small;}

      table {border-collapse: collapse; margin-bottom: 9px; margin-left: 6px;}
      th, td {text-align: left; padding: 3px;}
      th {background-color: #c1c1c1; color: black;}
      th:hover {color: #eb1c23;}
      tr:nth-child(even) {background-color: #f2f2f2;}
      tr:hover {background-color:#d9d9d9; color: #eb1c23}

      ul {line-height: 2;}
      ol {line-height: 1;}

      a:link {color:#138a94} <!-- dark teal -->
      a:visited {color:#8cc3db} <!-- light teal -->
      a:hover {color:#eb1c23} <!-- signal red -->
      a:active {color:#138a94} <!-- dark teal -->
    </style>
  </head>

<!-- BODY -->

  <body>
    <h1>Newsletter Report Analysis</h1>

<!-- TABLE OF CONTENT -->

    <h2>Table of Content</h2>

    <ol>
      <li><a href="#Overview">Overview</a></li>
      <li><a href="#Year_Overview">Year Overview</a></li>
      <li><a href="#Sender_Analysis">Sender Analysis</a></li>
      <li><a href="#Year-Over-Year_Analysis">Year-Over-Year Analysis</a></li>
        <ol>
          <li><a href="#Year-Over-Year_Analysis_2019">2019</a></li>
          <li><a href="#Year-Over-Year_Analysis_2018">2018</a></li>
          <li><a href="#Year-Over-Year_Analysis_2017">2017</a></li>
          <li><a href="#Year-Over-Year_Analysis_2016">2016</a></li>
          <li><a href="#Year-Over-Year_Analysis_2015">2015</a></li>
        </ol>
      <li><a href="#Test_Analysis">A/B Test Analysis</a></li>
        <ol>
          <li><a href="#Test_Analysis_2019">2019</a></li>
          <li><a href="#Test_Analysis_2018">2018</a></li>
        </ol>
      <li><a href="#Opening_Analysis">Opening Analysis</a></li>
        <ol>
          <li><a href="#Opening_Analysis_Above">Above-Average (<xsl:value-of select="format-number(sum(//my:stats/@open) div $No, '#.00')"/>&lt;)</a></li>
          <li><a href="#Opening_Analysis_Below">Below-Average (&lt;<xsl:value-of select="format-number(sum(//my:stats/@open) div $No, '#.00')"/>)</a></li>
          <li><a href="#Opening_Analysis_Outstanding">Outstanding (29&lt;)</a></li>
          <li><a href="#Opening_Analysis_Underperforming">Underperforming (&lt;26)</a></li>
        </ol>
      <li><a href="#Weekday_Analysis">Weekday Analysis</a></li>
      <li><a href="#Month_Analysis">Month Analysis</a></li>
      <li><a href="#Conclusion">Conclusion</a></li>
    </ol>

    <p id="note">(Last update: <xsl:value-of select="//my:update/@date"/>)</p>
    <!--p>
      <xsl:for-each select="my:year/my:month/my:meta/my:delivered/@date">
        <xsl:call-template name="calculate-day-of-the-week">
          <xsl:with-param name="date" select ="."/>
        </xsl:call-template>
      </xsl:for-each>
    </p-->

<!-- OVERVIEW -->

    <h2 id="Overview">Overview</h2>

    <table>
      <tr>
        <th>No.</th>
        <th>Open</th>
        <th>Klick</th>
        <th>Unsub</th>
      </tr>
      <tr>
       <td><xsl:value-of select="count(//my:delivered)"/></td>
       <td><xsl:value-of select="format-number(sum(//my:stats/@open) div $No, '#.00')"/></td>
       <td><xsl:value-of select="format-number(sum(//my:stats/@klick) div $No, '#.00')"/></td>
       <td><xsl:value-of select="format-number(sum(//my:stats/@unsub) div $No, '#.00')"/></td>
      </tr>
    </table>

<!-- YEAR OVERVIEW -->

    <h2 id="Year_Overview">Year Overview</h2>

    <table>
      <tr>
        <th>Year</th>
        <th>No.</th>
        <th>Open</th>
        <th>Klick</th>
        <th>Unsub</th>
      </tr>
      <xsl:for-each select="my:year/@yref">
        <xsl:call-template name="yearAnalysis">
          <xsl:with-param name="Y" select ="."/>
          <xsl:with-param name="C" select ="count(..//my:delivered)"/>
        </xsl:call-template>
      </xsl:for-each>
    </table>

<!-- SENDER ANALYSIS -->

    <h2 id="Sender_Analysis">Sender Analysis</h2>

    <table>
      <tr>
        <th>Sender</th>
        <th>No.</th>
        <th>Open</th>
        <th>Klick</th>
        <th>Unsub</th>
      </tr>
      <xsl:for-each select="//my:senderID/@sid">
      <xsl:call-template name="senderAnalysis">
        <xsl:with-param name="C" select ="."/>
      </xsl:call-template>
     </xsl:for-each>
    </table>

<!-- YEAR-OVER-YEAR ANALYSIS -->

    <h2 id="Year-Over-Year_Analysis">Year-Over-Year Analysis</h2>

    <!-- 2019 -->

    <h3 id="Year-Over-Year_Analysis_2019">2019</h3>

    <table>
      <tr>
        <th>Open</th>
        <th>Klick</th>
        <th>Unsub</th>
      </tr>
      <tr>
        <xsl:variable name="delivered" select="count(my:year[@yref='2019']//my:delivered)"/>
        <td><xsl:value-of select="format-number(sum(my:year[@yref='2019']/my:month/my:stats/@open) div $delivered, '#.00')"/></td>
        <td><xsl:value-of select="format-number(sum(my:year[@yref='2019']/my:month/my:stats/@klick) div $delivered, '#.00')"/></td>
        <td><xsl:value-of select="format-number(sum(my:year[@yref='2019']/my:month/my:stats/@unsub) div $delivered, '#.00')"/></td>
      </tr>
    </table>

    <table>
      <xsl:call-template name="analysisTableHead"/>
      <xsl:for-each select="my:year[@yref='2019']/my:month/@mref">
        <xsl:call-template name="monthAnalysis19">
          <xsl:with-param name="M" select ="."/>
        </xsl:call-template>
      </xsl:for-each>
    </table>

    <!-- 2018 -->

    <h3 id="Year-Over-Year_Analysis_2018">2018</h3>

    <table>
      <tr>
        <th>Open</th>
        <th>Klick</th>
        <th>Unsub</th>
      </tr>
      <tr>
        <xsl:variable name="delivered" select="count(my:year[@yref='2018']//my:delivered)"/>
        <td><xsl:value-of select="format-number(sum(my:year[@yref='2018']/my:month/my:stats/@open) div $delivered, '#.00')"/></td>
        <td><xsl:value-of select="format-number(sum(my:year[@yref='2018']/my:month/my:stats/@klick) div $delivered, '#.00')"/></td>
        <td><xsl:value-of select="format-number(sum(my:year[@yref='2018']/my:month/my:stats/@unsub) div $delivered, '#.00')"/></td>
      </tr>
    </table>

    <table>
      <xsl:call-template name="analysisTableHead"/>
      <xsl:for-each select="my:year[@yref='2018']/my:month/@mref">
        <xsl:call-template name="monthAnalysis18">
          <xsl:with-param name="M" select ="."/>
        </xsl:call-template>
      </xsl:for-each>
    </table>

    <!-- 2017 -->

    <h3 id="Year-Over-Year_Analysis_2017">2017</h3>

    <table>
      <tr>
        <th>Open</th>
        <th>Klick</th>
        <th>Unsub</th>
      </tr>
      <tr>
        <xsl:variable name="delivered" select="count(my:year[@yref='2017']//my:delivered)"/>
        <td><xsl:value-of select="format-number(sum(my:year[@yref='2017']/my:month/my:stats/@open) div $delivered, '#.00')"/></td>
        <td><xsl:value-of select="format-number(sum(my:year[@yref='2017']/my:month/my:stats/@klick) div $delivered, '#.00')"/></td>
        <td><xsl:value-of select="format-number(sum(my:year[@yref='2017']/my:month/my:stats/@unsub) div $delivered, '#.00')"/></td>
      </tr>
    </table>

    <table>
      <xsl:call-template name="analysisTableHead"/>
      <xsl:for-each select="my:year[@yref='2017']/my:month/@mref">
        <xsl:call-template name="monthAnalysis17">
          <xsl:with-param name="M" select ="."/>
        </xsl:call-template>
     </xsl:for-each>
    </table>

    <!-- 2016 -->

    <h3 id="Year-Over-Year_Analysis_2016">2016</h3>

    <table>
      <tr>
        <th>Open</th>
        <th>Klick</th>
        <th>Unsub</th>
      </tr>
      <tr>
        <xsl:variable name="delivered" select="count(my:year[@yref='2016']//my:delivered)"/>
        <td><xsl:value-of select="format-number(sum(my:year[@yref='2016']/my:month/my:stats/@open) div $delivered, '#.00')"/></td>
        <td><xsl:value-of select="format-number(sum(my:year[@yref='2016']/my:month/my:stats/@klick) div $delivered, '#.00')"/></td>
        <td><xsl:value-of select="format-number(sum(my:year[@yref='2016']/my:month/my:stats/@unsub) div $delivered, '#.00')"/></td>
      </tr>
    </table>

    <table>
      <xsl:call-template name="analysisTableHead"/>
      <xsl:for-each select="my:year[@yref='2016']/my:month/@mref">
        <xsl:call-template name="monthAnalysis16">
          <xsl:with-param name="M" select ="."/>
        </xsl:call-template>
      </xsl:for-each>
    </table>

    <!-- 2015 -->

    <h3 id="Year-Over-Year_Analysis_2015">2015</h3>

    <table>
      <tr>
        <th>Open</th>
        <th>Klick</th>
        <th>Unsub</th>
      </tr>
      <tr>
        <xsl:variable name="delivered" select="count(my:year[@yref='2015']//my:delivered)"/>
        <td><xsl:value-of select="format-number(sum(my:year[@yref='2015']/my:month/my:stats/@open) div $delivered, '#.00')"/></td>
        <td><xsl:value-of select="format-number(sum(my:year[@yref='2015']/my:month/my:stats/@klick) div $delivered, '#.00')"/></td>
        <td><xsl:value-of select="format-number(sum(my:year[@yref='2015']/my:month/my:stats/@unsub) div $delivered, '#.00')"/></td>
      </tr>
    </table>

    <table>
      <xsl:call-template name="analysisTableHead"/>
      <xsl:for-each select="my:year[@yref='2015']/my:month/@mref">
        <xsl:call-template name="monthAnalysis15">
          <xsl:with-param name="M" select ="."/>
        </xsl:call-template>
      </xsl:for-each>
    </table>

<!-- A/B TEST ANALYSIS -->

    <h2 id="Test_Analysis">A/B Test Analysis</h2>

    <!-- 2019 -->

    <h3 id="Test_Analysis_2019">2019</h3>

    <table>
      <tr>
        <th>Month</th>
        <th>Subject 1</th>
        <th>Subject 0</th>
        <th>Open 1</th>
        <th>Open 0</th>
        <th>Klick 1</th>
        <th>Klick 0</th>
      </tr>
      <xsl:for-each select="my:year[@yref='2019']/my:month/@mref">
        <xsl:call-template name="testAnalysis19">
          <xsl:with-param name="M" select ="."/>
        </xsl:call-template>
      </xsl:for-each>
    </table>

    <!-- 2018 -->

    <h3 id="Test_Analysis_2018">2018</h3>

    <table>
      <tr>
        <th>Month</th>
        <th>Subject 1</th>
        <th>Subject 0</th>
        <th>Open 1</th>
        <th>Open 0</th>
        <th>Klick 1</th>
        <th>Klick 0</th>
      </tr>
      <xsl:for-each select="my:year[@yref='2018']/my:month/@mref">
        <xsl:call-template name="testAnalysis18">
          <xsl:with-param name="M" select ="."/>
        </xsl:call-template>
      </xsl:for-each>
    </table>

<!-- OPENING ANALYSIS -->

    <h2 id="Opening_Analysis">Opening Analysis</h2>

    <!-- ABOVE AVERAGE -->

    <h3 id="Opening_Analysis_Above">Above-Average (<xsl:value-of select="format-number(sum(//my:stats/@open) div $No, '#.00')"/>&lt;)</h3>

    <table>
      <xsl:call-template name="analysisTableHead"/>
      <xsl:for-each select="//my:delivered">
        <xsl:if test="../../my:stats/@open>(sum(//my:stats/@open) div $No)">
          <xsl:call-template name="openingAnalysis">
            <xsl:with-param name="S" select="../my:subject"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:for-each>
    </table>

    <!-- BELOW AVERAGE -->

    <h3 id="Opening_Analysis_Below">Below-Average (&lt;<xsl:value-of select="format-number(sum(//my:stats/@open) div $No, '#.00')"/>)</h3>

    <table>
      <xsl:call-template name="analysisTableHead"/>
      <xsl:for-each select="//my:delivered">
        <xsl:if test="../../my:stats/@open&lt;(sum(//my:stats/@open) div $No)">
          <xsl:call-template name="openingAnalysis">
            <xsl:with-param name="S" select="../my:subject"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:for-each>
    </table>

    <!-- OUTSTANDING -->

    <h3 id="Opening_Analysis_Outstanding">Outstanding (29&lt;)</h3>

    <table>
      <xsl:call-template name="analysisTableHead"/>
      <xsl:for-each select="//my:delivered">
        <xsl:if test="../../my:stats/@open>29">
          <xsl:call-template name="openingAnalysis">
            <xsl:with-param name="S" select="../my:subject"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:for-each>
    </table>

    <!-- UNDERPERFORMING -->

    <h3 id="Opening_Analysis_Underperforming">Underperforming (&lt;26)</h3>

    <table>
      <xsl:call-template name="analysisTableHead"/>
      <xsl:for-each select="//my:delivered">
        <xsl:if test="../../my:stats/@open&lt;26">
          <xsl:call-template name="openingAnalysis">
            <xsl:with-param name="S" select="../my:subject"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:for-each>
    </table>

<!-- WEEKDAY ANALYSIS -->

    <h2 id="Weekday_Analysis">Weekday Analysis</h2>

    <table>
      <tr>
        <th>Day</th>
        <th>Share</th>
      </tr>
      <tr>
        <td>Sunday</td>
        <td>
          <xsl:for-each select="//my:delivered/@date">
            <xsl:call-template name="calculate-sun">
              <xsl:with-param name="date" select ="."/>
            </xsl:call-template>
          </xsl:for-each>
        </td>
      </tr>
      <tr>
        <td>Monday</td>
        <td>
          <xsl:for-each select="//my:delivered/@date">
            <xsl:call-template name="calculate-mon">
              <xsl:with-param name="date" select ="."/>
            </xsl:call-template>
          </xsl:for-each>
        </td>
      </tr>
      <tr>
        <td>Tuesday</td>
        <td>
          <xsl:for-each select="//my:delivered/@date">
            <xsl:call-template name="calculate-tue">
              <xsl:with-param name="date" select ="."/>
            </xsl:call-template>
          </xsl:for-each>
        </td>
      </tr>
      <tr>
        <td>Wednesday</td>
        <td>
          <xsl:for-each select="//my:delivered/@date">
            <xsl:call-template name="calculate-wed">
              <xsl:with-param name="date" select ="."/>
            </xsl:call-template>
          </xsl:for-each>
        </td>
      </tr>
      <tr>
        <td>Thursday</td>
        <td>
          <xsl:for-each select="//my:delivered/@date">
            <xsl:call-template name="calculate-thu">
              <xsl:with-param name="date" select ="."/>
            </xsl:call-template>
          </xsl:for-each>
        </td>
      </tr>
      <tr>
        <td>Friday</td>
        <td>
          <xsl:for-each select="//my:delivered/@date">
            <xsl:call-template name="calculate-fri">
              <xsl:with-param name="date" select ="."/>
            </xsl:call-template>
          </xsl:for-each>
        </td>
      </tr>
      <tr>
        <td>Saturday</td>
        <td>
          <xsl:for-each select="//my:delivered/@date">
            <xsl:call-template name="calculate-sat">
              <xsl:with-param name="date" select ="."/>
            </xsl:call-template>
          </xsl:for-each>
        </td>
      </tr>
    </table>

<!-- MONTH ANALYSIS -->

    <h2 id="Month_Analysis">Month Analysis</h2>

    <table>
      <tr>
        <th>Mo.</th>
        <th>Open</th>
        <th>Above-Average</th>
      </tr>
      <xsl:for-each select="my:year[@yref='2019']/my:month">
        <xsl:call-template name="generalMonthAnalysis">
          <xsl:with-param name="MREF" select="@mref"/>
        </xsl:call-template>
      </xsl:for-each>
    </table>

<!-- CONCLUSION -->

    <h2 id="Conclusion">Conclusion</h2>

    <ul>
    <li>Do not send newsletters on Fridays, but at the beginning of the week (Monday/Tuesday) and test the end of the week (Saturday/Sunday) as an alternative; time of day seems to be irrelevant.</li>

    <li>Use curious constructions - don't reveal too much <i>("RWE ohne Badehose beim Schwimmunterricht", "Geld und Huhn", "RWE: Naherholungsgebiet Abbruchkante")</i>.</li>

    <li>Use emotionally charged words <i>("Krieg", "Sieg", "Waffen")</i> and avoid worn-out words <i>("Klima"/"Klimawandel"/"Klimaschutz", "Kohle-Ausstieg")</i>.</li>

    <li>Refrain from obvious self-praise <i>("Wir haben Milliarden bewegt!", "urgewald schreibt Divestment-Geschichte", "Unser neuer Riesenerfolg!")</i>.</li>

    <li>Avoid confusion with advertising/spam mails <i>("urgewald: Jetzt auch zum Verschenken!", "Wenn Sie wüssten...")</i>.</li>

    <li>And if nothing works out, "RWE" always does <i>("RWE-Kritik zur besten Sendezeit", "Den Sieg zur Niederlage machen, das schafft nur RWE", …)</i>!</li>
    </ul>

  </body>
</html>
</xsl:template>

<!-- TEMPLATES (AS CHILDREN OF STYLESHEET) -->

<!-- yearAnalysis -->

<xsl:template name="yearAnalysis">
  <xsl:param name="Y"/>
  <xsl:param name="C"/>
  <tr>
   <td><xsl:value-of select="$Y"/></td>
   <td><xsl:value-of select="$C"/></td>
   <td><xsl:value-of select="format-number(sum(//my:year[@yref=$Y]/my:month/my:stats/@open) div $C, '#.00')"/></td>
   <td><xsl:value-of select="format-number(sum(//my:year[@yref=$Y]/my:month/my:stats/@klick) div $C, '#.00')"/></td>
   <td><xsl:value-of select="format-number(sum(//my:year[@yref=$Y]/my:month/my:stats/@unsub) div $C, '#.00')"/></td>
  </tr>
</xsl:template>

<!-- senderAnalysis -->

<xsl:template name="senderAnalysis">
  <xsl:param name="C"/>
  <xsl:param name="Z" select ="count(//my:sender[@sref=$C])"/>
  <tr>
   <td><xsl:value-of select="$C"/></td>
   <td><xsl:value-of select="count(//my:sender[@sref=$C])"/></td> <!-- $Z -->
   <td><xsl:value-of select="format-number(sum(//my:month/my:meta[my:sender[@sref=$C]]/../my:stats/@open) div $Z, '#.00')"/></td>
   <td><xsl:value-of select="format-number(sum(//my:month/my:meta[my:sender[@sref=$C]]/../my:stats/@klick) div $Z, '#.00')"/></td>
   <td><xsl:value-of select="format-number(sum(//my:month/my:meta[my:sender[@sref=$C]]/../my:stats/@unsub) div $Z, '#.00')"/></td>
  </tr>
</xsl:template>

<!-- analysisTableHead -->

<xsl:template name="analysisTableHead">
  <tr>
    <th>Month</th>
    <th>Sender</th>
    <th>Subject</th>
    <th>Date</th>
    <th>Time</th>
    <th>Day</th>
    <th>Open</th>
    <th>Klick</th>
    <th>Unsub</th>
  </tr>
</xsl:template>

<xsl:template name="monthAnalysis19"> <!-- monthAnalysis19 -->
  <xsl:param name="M"/>
  <tr>
    <td><xsl:value-of select="substring-after($M, '--')"/></td>
    <td><xsl:value-of select="//my:year[@yref='2019']/my:month[@mref=$M]/my:meta/my:sender/@sref"/></td>
    <td><xsl:value-of select="//my:year[@yref='2019']/my:month[@mref=$M]/my:meta/my:subject"/></td>
    <td><xsl:value-of select="//my:year[@yref='2019']/my:month[@mref=$M]/my:meta/my:delivered/@date"/></td>
    <td><xsl:value-of select="substring(//my:year[@yref='2019']/my:month[@mref=$M]/my:meta/my:delivered/@time, 0, 6)"/></td>
    <td>
      <xsl:call-template name="calculate-day-of-the-week">
        <xsl:with-param name="date" select ="//my:year[@yref='2019']/my:month[@mref=$M]/my:meta/my:delivered/@date"/>
      </xsl:call-template>
    </td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2019']/my:month[@mref=$M]/my:stats/@open, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2019']/my:month[@mref=$M]/my:stats/@klick, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2019']/my:month[@mref=$M]/my:stats/@unsub, '#.00')"/></td>
  </tr>
</xsl:template>

<xsl:template name="monthAnalysis18"> <!-- monthAnalysis18 -->
  <xsl:param name="M"/>
  <tr>
    <td><xsl:value-of select="substring-after($M, '--')"/></td>
    <td><xsl:value-of select="//my:year[@yref='2018']/my:month[@mref=$M]/my:meta/my:sender/@sref"/></td>
    <td><xsl:value-of select="//my:year[@yref='2018']/my:month[@mref=$M]/my:meta/my:subject"/></td>
    <td><xsl:value-of select="//my:year[@yref='2018']/my:month[@mref=$M]/my:meta/my:delivered/@date"/></td>
    <td><xsl:value-of select="substring(//my:year[@yref='2018']/my:month[@mref=$M]/my:meta/my:delivered/@time, 0, 6)"/></td>
    <td>
      <xsl:call-template name="calculate-day-of-the-week">
        <xsl:with-param name="date" select ="//my:year[@yref='2018']/my:month[@mref=$M]/my:meta/my:delivered/@date"/>
      </xsl:call-template>
    </td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2018']/my:month[@mref=$M]/my:stats/@open, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2018']/my:month[@mref=$M]/my:stats/@klick, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2018']/my:month[@mref=$M]/my:stats/@unsub, '#.00')"/></td>
  </tr>
</xsl:template>

<xsl:template name="monthAnalysis17"> <!-- monthAnalysis17 -->
  <xsl:param name="M"/>
  <tr>
    <td><xsl:value-of select="substring-after($M, '--')"/></td>
    <td><xsl:value-of select="//my:year[@yref='2017']/my:month[@mref=$M]/my:meta/my:sender/@sref"/></td>
    <td><xsl:value-of select="//my:year[@yref='2017']/my:month[@mref=$M]/my:meta/my:subject"/></td>
    <td><xsl:value-of select="//my:year[@yref='2017']/my:month[@mref=$M]/my:meta/my:delivered/@date"/></td>
    <td><xsl:value-of select="substring(//my:year[@yref='2017']/my:month[@mref=$M]/my:meta/my:delivered/@time, 0, 6)"/></td>
    <td>
      <xsl:call-template name="calculate-day-of-the-week">
        <xsl:with-param name="date" select ="//my:year[@yref='2017']/my:month[@mref=$M]/my:meta/my:delivered/@date"/>
      </xsl:call-template>
    </td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2017']/my:month[@mref=$M]/my:stats/@open, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2017']/my:month[@mref=$M]/my:stats/@klick, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2017']/my:month[@mref=$M]/my:stats/@unsub, '#.00')"/></td>
  </tr>
</xsl:template>

<xsl:template name="monthAnalysis16"> <!-- monthAnalysis16 -->
  <xsl:param name="M"/>
  <tr>
    <td><xsl:value-of select="substring-after($M, '--')"/></td>
    <td><xsl:value-of select="//my:year[@yref='2016']/my:month[@mref=$M]/my:meta/my:sender/@sref"/></td>
    <td><xsl:value-of select="//my:year[@yref='2016']/my:month[@mref=$M]/my:meta/my:subject"/></td>
    <td><xsl:value-of select="//my:year[@yref='2016']/my:month[@mref=$M]/my:meta/my:delivered/@date"/></td>
    <td><xsl:value-of select="substring(//my:year[@yref='2016']/my:month[@mref=$M]/my:meta/my:delivered/@time, 0, 6)"/></td>
    <td>
      <xsl:call-template name="calculate-day-of-the-week">
        <xsl:with-param name="date" select ="//my:year[@yref='2016']/my:month[@mref=$M]/my:meta/my:delivered/@date"/>
      </xsl:call-template>
    </td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2016']/my:month[@mref=$M]/my:stats/@open, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2016']/my:month[@mref=$M]/my:stats/@klick, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2016']/my:month[@mref=$M]/my:stats/@unsub, '#.00')"/></td>
  </tr>
</xsl:template>

<xsl:template name="monthAnalysis15"> <!-- monthAnalysis15 -->
  <xsl:param name="M"/>
  <tr>
    <td><xsl:value-of select="substring-after($M, '--')"/></td>
    <td><xsl:value-of select="//my:year[@yref='2015']/my:month[@mref=$M]/my:meta/my:sender/@sref"/></td>
    <td><xsl:value-of select="//my:year[@yref='2015']/my:month[@mref=$M]/my:meta/my:subject"/></td>
    <td><xsl:value-of select="//my:year[@yref='2015']/my:month[@mref=$M]/my:meta/my:delivered/@date"/></td>
    <td><xsl:value-of select="substring(//my:year[@yref='2015']/my:month[@mref=$M]/my:meta/my:delivered/@time, 0, 6)"/></td>
    <td>
      <xsl:call-template name="calculate-day-of-the-week">
        <xsl:with-param name="date" select ="//my:year[@yref='2015']/my:month[@mref=$M]/my:meta/my:delivered/@date"/>
      </xsl:call-template>
    </td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2015']/my:month[@mref=$M]/my:stats/@open, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2015']/my:month[@mref=$M]/my:stats/@klick, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2015']/my:month[@mref=$M]/my:stats/@unsub, '#.00')"/></td>
  </tr>
</xsl:template>

<xsl:template name="testAnalysis19"> <!-- testAnalysis19 -->
  <xsl:param name="M"/>
  <tr>
    <td><xsl:value-of select="substring-after($M, '--')"/></td>
    <td><xsl:value-of select="//my:year[@yref='2019']/my:month[@mref=$M]/my:test/*[@win=1]"/></td>
    <td><xsl:value-of select="//my:year[@yref='2019']/my:month[@mref=$M]/my:test/*[@win=0]"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2019']/my:month[@mref=$M]/my:test/*[@win=1]/@open, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2019']/my:month[@mref=$M]/my:test/*[@win=0]/@open, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2019']/my:month[@mref=$M]/my:test/*[@win=1]/@klick, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2019']/my:month[@mref=$M]/my:test/*[@win=0]/@klick, '#.00')"/></td>
  </tr>
</xsl:template>

<xsl:template name="testAnalysis18"> <!-- testAnalysis18 -->
  <xsl:param name="M"/>
  <tr>
    <td><xsl:value-of select="substring-after($M, '--')"/></td>
    <td><xsl:value-of select="//my:year[@yref='2018']/my:month[@mref=$M]/my:test/*[@win=1]"/></td>
    <td><xsl:value-of select="//my:year[@yref='2018']/my:month[@mref=$M]/my:test/*[@win=0]"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2018']/my:month[@mref=$M]/my:test/*[@win=1]/@open, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2018']/my:month[@mref=$M]/my:test/*[@win=0]/@open, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2018']/my:month[@mref=$M]/my:test/*[@win=1]/@klick, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year[@yref='2018']/my:month[@mref=$M]/my:test/*[@win=0]/@klick, '#.00')"/></td>
  </tr>
</xsl:template>

<!-- openingAnalysis -->

<xsl:template name="openingAnalysis">
  <xsl:param name="S"/>
  <tr>
    <td><xsl:value-of select="substring-after(//my:year/my:month/my:meta/my:subject[text()=$S]/../../@mref, '--')"/></td>
    <td><xsl:value-of select="//my:year/my:month/my:meta/my:subject[text()=$S]/../my:sender/@sref"/></td>
    <td><xsl:value-of select="//my:year/my:month/my:meta/my:subject[text()=$S]"/></td>
    <td><xsl:value-of select="//my:year/my:month/my:meta/my:subject[text()=$S]/../my:delivered/@date"/></td>
    <td><xsl:value-of select="substring(//my:year/my:month/my:meta/my:subject[text()=$S]/../my:delivered/@time, 0, 6)"/></td>
    <td>
      <xsl:call-template name="calculate-day-of-the-week">
        <xsl:with-param name="date" select ="//my:year/my:month/my:meta/my:subject[text()=$S]/../my:delivered/@date"/>
      </xsl:call-template>
    </td>
    <td><xsl:value-of select="format-number(//my:year/my:month/my:meta/my:subject[text()=$S]/../../my:stats/@open, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year/my:month/my:meta/my:subject[text()=$S]/../../my:stats/@klick, '#.00')"/></td>
    <td><xsl:value-of select="format-number(//my:year/my:month/my:meta/my:subject[text()=$S]/../../my:stats/@unsub, '#.00')"/></td>
  </tr>
</xsl:template>

<!-- calculate-day-of-the-week (#0 to #6)-->
<!-- source (modified): https://www.oreilly.com/library/view/xslt-cookbook-2nd/0596009747/ch04.html - 0=Sunday -->

<xsl:template name="calculate-day-of-the-week">
  <xsl:param name="date"/>
  <xsl:param name="year" select="substring-before($date,'-')"/>
  <xsl:param name="month" select="substring-before(substring-after($date,'-'),'-')"/>
  <xsl:param name="day" select="substring-after(substring-after($date,'-'),'-')"/>
  <xsl:variable name="a" select="floor((14 - $month) div 12)"/>
  <xsl:variable name="y" select="$year - $a"/>
  <xsl:variable name="m" select="$month + 12 * $a - 2"/>
  #<xsl:value-of select="($day + $y + floor($y div 4) - floor($y div 100) + floor($y div 400) + floor((31 * $m) div 12)) mod 7"/>
</xsl:template>

<!-- calculate-xxx (Weekday Analysis - table)-->

<xsl:template name="calculate-sun">
  <xsl:param name="date"/>
  <xsl:param name="year" select="substring-before($date,'-')"/>
  <xsl:param name="month" select="substring-before(substring-after($date,'-'),'-')"/>
  <xsl:param name="day" select="substring-after(substring-after($date,'-'),'-')"/>
  <xsl:variable name="a" select="floor((14 - $month) div 12)"/>
  <xsl:variable name="y" select="$year - $a"/>
  <xsl:variable name="m" select="$month + 12 * $a - 2"/>
  <xsl:if test="(($day + $y + floor($y div 4) - floor($y div 100) + floor($y div 400) + floor((31 * $m) div 12)) mod 7) = 0">
    #<!--xsl:value-of select="count($date)"/-->
  </xsl:if>
</xsl:template>

<xsl:template name="calculate-mon">
  <xsl:param name="date"/>
  <xsl:param name="year" select="substring-before($date,'-')"/>
  <xsl:param name="month" select="substring-before(substring-after($date,'-'),'-')"/>
  <xsl:param name="day" select="substring-after(substring-after($date,'-'),'-')"/>
  <xsl:variable name="a" select="floor((14 - $month) div 12)"/>
  <xsl:variable name="y" select="$year - $a"/>
  <xsl:variable name="m" select="$month + 12 * $a - 2"/>
  <xsl:if test="(($day + $y + floor($y div 4) - floor($y div 100) + floor($y div 400) + floor((31 * $m) div 12)) mod 7) = 1">
    #<!--xsl:value-of select="count($date)"/-->
  </xsl:if>
</xsl:template>

<xsl:template name="calculate-tue">
  <xsl:param name="date"/>
  <xsl:param name="year" select="substring-before($date,'-')"/>
  <xsl:param name="month" select="substring-before(substring-after($date,'-'),'-')"/>
  <xsl:param name="day" select="substring-after(substring-after($date,'-'),'-')"/>
  <xsl:variable name="a" select="floor((14 - $month) div 12)"/>
  <xsl:variable name="y" select="$year - $a"/>
  <xsl:variable name="m" select="$month + 12 * $a - 2"/>
  <xsl:if test="(($day + $y + floor($y div 4) - floor($y div 100) + floor($y div 400) + floor((31 * $m) div 12)) mod 7) = 2">
    #<!--xsl:value-of select="count($date)"/-->
  </xsl:if>
</xsl:template>

<xsl:template name="calculate-wed">
  <xsl:param name="date"/>
  <xsl:param name="year" select="substring-before($date,'-')"/>
  <xsl:param name="month" select="substring-before(substring-after($date,'-'),'-')"/>
  <xsl:param name="day" select="substring-after(substring-after($date,'-'),'-')"/>
  <xsl:variable name="a" select="floor((14 - $month) div 12)"/>
  <xsl:variable name="y" select="$year - $a"/>
  <xsl:variable name="m" select="$month + 12 * $a - 2"/>
  <xsl:if test="(($day + $y + floor($y div 4) - floor($y div 100) + floor($y div 400) + floor((31 * $m) div 12)) mod 7) = 3">
    #<!--xsl:value-of select="count($date)"/-->
  </xsl:if>
</xsl:template>

<xsl:template name="calculate-thu">
  <xsl:param name="date"/>
  <xsl:param name="year" select="substring-before($date,'-')"/>
  <xsl:param name="month" select="substring-before(substring-after($date,'-'),'-')"/>
  <xsl:param name="day" select="substring-after(substring-after($date,'-'),'-')"/>
  <xsl:variable name="a" select="floor((14 - $month) div 12)"/>
  <xsl:variable name="y" select="$year - $a"/>
  <xsl:variable name="m" select="$month + 12 * $a - 2"/>
  <xsl:if test="(($day + $y + floor($y div 4) - floor($y div 100) + floor($y div 400) + floor((31 * $m) div 12)) mod 7) = 4">
    #<!--xsl:value-of select="count($date)"/-->
  </xsl:if>
</xsl:template>

<xsl:template name="calculate-fri">
  <xsl:param name="date"/>
  <xsl:param name="year" select="substring-before($date,'-')"/>
  <xsl:param name="month" select="substring-before(substring-after($date,'-'),'-')"/>
  <xsl:param name="day" select="substring-after(substring-after($date,'-'),'-')"/>
  <xsl:variable name="a" select="floor((14 - $month) div 12)"/>
  <xsl:variable name="y" select="$year - $a"/>
  <xsl:variable name="m" select="$month + 12 * $a - 2"/>
  <xsl:if test="(($day + $y + floor($y div 4) - floor($y div 100) + floor($y div 400) + floor((31 * $m) div 12)) mod 7) = 5">
    #<!--xsl:value-of select="count($date)"/-->
  </xsl:if>
</xsl:template>

<xsl:template name="calculate-sat">
  <xsl:param name="date"/>
  <xsl:param name="year" select="substring-before($date,'-')"/>
  <xsl:param name="month" select="substring-before(substring-after($date,'-'),'-')"/>
  <xsl:param name="day" select="substring-after(substring-after($date,'-'),'-')"/>
  <xsl:variable name="a" select="floor((14 - $month) div 12)"/>
  <xsl:variable name="y" select="$year - $a"/>
  <xsl:variable name="m" select="$month + 12 * $a - 2"/>
  <xsl:if test="(($day + $y + floor($y div 4) - floor($y div 100) + floor($y div 400) + floor((31 * $m) div 12)) mod 7) = 6">
    #<!--xsl:value-of select="count($date)"/-->
  </xsl:if>
</xsl:template>

<!-- generalMonthAnalysis -->

<xsl:template name="generalMonthAnalysis">
  <xsl:param name="MREF"/>
  <tr>
    <td><xsl:value-of select="substring-after($MREF, '--')"/></td>
    <td>
      <xsl:value-of select="format-number(sum(//my:month[@mref=$MREF]/my:stats/@open) div count(//my:month[@mref=$MREF]/my:stats), '#.00')"/>
    </td>
    <td>
      <xsl:for-each select="//my:month[@mref=$MREF]">
        <xsl:if test="my:stats/@open>(sum(//my:stats/@open) div count(//my:delivered))">
          #<!--xsl:value-of select="count($date)"/-->
        </xsl:if>
      </xsl:for-each>
    </td>
  </tr>
</xsl:template>

</xsl:stylesheet>
